## What

<!-- Brief description of changes -->

## Why

<!-- Motivation / issue link -->

## Checklist

- [ ] Tests pass (`pytest tests/`)
- [ ] Linting passes (`ruff check src/`)
- [ ] Documentation updated (if applicable)
- [ ] Changelog updated (if applicable)
